@@ -6,9 +6,7 @@
 #include "plugin.h"
 #include "internal.h"
 
-zathura_error_t
-cb_page_init(zathura_page_t* page)
-{
+zathura_error_t cb_page_init(zathura_page_t* page) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -38,9 +36,7 @@ cb_page_init(zathura_page_t* page)
   return ZATHURA_ERROR_OK;
 }
 
-zathura_error_t
-cb_page_clear(zathura_page_t* UNUSED(page), void* data)
-{
+zathura_error_t cb_page_clear(zathura_page_t* UNUSED(page), void* data) {
   cb_page_t* cb_page = data;
   if (cb_page == NULL) {
     return ZATHURA_ERROR_OK;
